//
//  PhotoKitService.swift
//  RemoteImage
//
//  Created by Christian Elies.
//

import Photos

protocol PhotoKitServiceProvider {
	var photoKitService: PhotoKitServiceProtocol { get }
}

protocol PhotoKitServiceProtocol {
    func getPhotoData(
//        localIdentifier: String,
        asset: PHAsset,
//        _ completion: @escaping (Result<Data, Error>) -> Void
        _ completion: @escaping (Result<UniversalImage, Error>) -> Void
    )
}

final class PhotoKitService {
    static var asset: PHAsset.Type = PHAsset.self
    static var imageManager: PHImageManager = PHImageManager.default()
}

extension PhotoKitService: PhotoKitServiceProtocol {
    func getPhotoData(
//        localIdentifier: String,
        asset: PHAsset,
//        _ completion: @escaping (Result<Data, Error>) -> Void
        _ completion: @escaping (Result<UniversalImage, Error>) -> Void
    ) {
        
        let squareSize = CGSize(width: 150, height: 150)
        let manager = PHCachingImageManager.default()
        let requestOptions = PHImageRequestOptions()
        requestOptions.isSynchronous = true
        requestOptions.isNetworkAccessAllowed = true

//        var thumbnail = UIImage()

        manager.requestImage(for: asset, targetSize: squareSize, contentMode: .aspectFill, options: requestOptions) { (image, _) in
            if let image = image {
//                completion(.success(image.pngData()!))
                completion(.success(image))
            } else {
                completion(.failure(PhotoKitServiceError.missingData))
            }
        }
        
////        let fetchAssetsResult = Self.asset.fetchAssets(withLocalIdentifiers: [localIdentifier], options: nil)
//        let fetchAssetsResult = Self.asset.fetchAssets(withLocalIdentifiers: [asset.localIdentifier], options: <#T##PHFetchOptions?#>)
//        guard let phAsset = fetchAssetsResult.firstObject else {
////            completion(.failure(PhotoKitServiceError.phAssetNotFound(localIdentifier: localIdentifier)))
//            completion(.failure(PhotoKitServiceError.phAssetNotFound(asset: asset)))
//            return
//        }
//
//        let options = PHImageRequestOptions()
//        options.isNetworkAccessAllowed = true
//        Self.imageManager.requestImageDataAndOrientation(for: phAsset,
//                                                         options: options,
//                                                         resultHandler: { data, _, _, info in
//            if let error = info?[PHImageErrorKey] as? Error {
//                completion(.failure(error))
//            } else if let data = data {
//                completion(.success(data))
//            } else {
//                completion(.failure(PhotoKitServiceError.missingData))
//            }
//        })
    }
}
